export declare function getHighestBit(n: number): number;
/**
 * Gets the size of a number if it were to be encoded in unsigned LEB128
 *
 * @param n - Number not encoded.
 * @returns Width of the encoded number in bytes.
 */
export declare function getLEB128USize(n: number): number;
/**
 * Gets the size of a number if it were to be encoded in signed LEB128
 *
 * @param n - Number not encoded.
 * @returns Width of the encoded number in bytes.
 */
export declare function getLEB128SSize(n: number): number;
/**
 * Converts a number n to unsigned LEB128
 *
 * @param n - Must be an integer.
 * @param buffer - Buffer to write into
 * @param startIndex - Start index for writing
 * @returns End index for encoder.
 */
export declare function toLEB128U(n: number, buffer: Uint8Array, startIndex: number): number;
/**
 * Converts a number n to signed LEB128
 *
 * @param n - Must be an integer.
 * @param buffer - Buffer to write into
 * @param startIndex - Start index for writing
 * @returns End index for encoder.
 */
export declare function toLEB128S(n: number, buffer: Uint8Array, startIndex: number): number;
/**
 * Converts an unsigned LEB128 number to a JavaScript number, along with the
 * new end index
 *
 * @param buffer - Byte array for encoded values.
 * @param index - Where we read the value
 * @returns The integer value at buffer[index] along with the end index + 1.
 */
export declare function fromLEB128U(buffer: Uint8Array, index: number): {
    index: number;
    value: number;
};
/**
 * Converts a signed LEB128 number to a JavaScript number, returns the
 * number and the updated buffer index
 *
 * @param buffer - Byte array for encoded values.
 * @param index - Where we read the value
 * @returns The integer value at buffer[index] along with the end index + 1.
 */
export declare function fromLEB128S(buffer: Uint8Array, index: number): {
    index: number;
    value: number;
};
