import { Code, CodeSection, CustomSection, DataCountSection, DataSection, ElementSection, ExportSection, FunctionSection, FuncType, GlobalSection, Import, ImportSection, MemorySection, Module, StartSection, TableSection, TableType, TypeSection } from './wasm';
export declare function getFuncTypeSize(funcType: FuncType): number;
export declare function getImportEntrySize(importEntry: Import): number;
export declare function getTableTypeSize(tableType: TableType): number;
export declare function getCodeSize(body: Code): number;
export declare function getVecSize<T>(entries: T[], sizeFn: (e: T) => number): number;
/**
 * Gets size of type section, excluding
 * the standard section preamble
 *
 * @param typeSection - Types section.
 * @returns Size of types section in bytes
 */
export declare function getTypeSectionSize(typeSection: TypeSection): number;
/**
 * Gets size of import section, excluding
 * the standard section preamble
 *
 * @param importSection - Import section.
 * @returns Size of import section in bytes
 */
export declare function getImportSectionSize(importSection: ImportSection): number;
/**
 * Gets size of function section, excluding
 * the standard section preamble
 *
 * @param functionSection - function section.
 * @returns Size of function section in bytes
 */
export declare function getFunctionSectionSize(functionSection: FunctionSection): number;
/**
 * Gets size of table section, excluding
 * the standard section preamble
 *
 * @param tableSection - table section.
 * @returns Size of table section in bytes
 */
export declare function getTableSectionSize(tableSection: TableSection): number;
/**
 * Gets size of memory section, excluding
 * the standard section preamble
 *
 * @param memorySection - memory section.
 * @returns Size of memory section in bytes
 */
export declare function getMemorySectionSize(memorySection: MemorySection): number;
/**
 * Gets size of global section, excluding
 * the standard section preamble
 *
 * @param globalSection - global section.
 * @returns Size of global section in bytes
 */
export declare function getGlobalSectionSize(globalSection: GlobalSection): number;
/**
 * Gets size of export section, excluding
 * the standard section preamble
 *
 * @param exportSection - export section.
 * @returns Size of export section in bytes
 */
export declare function getExportSectionSize(exportSection: ExportSection): number;
/**
 * Gets size of start section, excluding
 * the standard section preamble
 *
 * @param startSection - start section.
 * @returns Size of start section in bytes
 */
export declare function getStartSectionSize(startSection: StartSection): number;
/**
 * Gets size of element section, excluding
 * the standard section preamble
 *
 * @param elementSection - element section.
 * @returns Size of element section in bytes
 */
export declare function getElementSectionSize(elementSection: ElementSection): number;
/**
 * Gets size of code section, excluding
 * the standard section preamble
 *
 * @param codeSection - code section.
 * @returns Size of code section in bytes
 */
export declare function getCodeSectionSize(codeSection: CodeSection): number;
/**
 * Gets size of data section, excluding
 * the standard section preamble
 *
 * @param dataSection - data section.
 * @returns Size of data section in bytes
 */
export declare function getDataSectionSize(dataSection: DataSection): number;
/**
 * Gets size of data count section, excluding
 * the standard section preamble
 *
 * @param dataCountSection - data count section.
 * @returns Size of data count section in bytes
 */
export declare function getDataCountSection(dataCountSection: DataCountSection): number;
/**
 * Gets size of custom sections, excluding
 * the standard section preamble
 *
 * @param customSections - array of custom sections.
 * @returns Size of custom section in bytes
 */
export declare function getCustomSectionsSize(customSections: CustomSection[]): number;
export interface SizeInfo {
    total: number;
    sections: {
        [Property in keyof Module]?: number;
    };
}
export declare function getModuleSize(module: Module): SizeInfo;
