export declare const VERSION = 1;
export declare const MAGIC_NUMBER = 1836278016;
declare type FuncId = number;
export declare enum NumType {
    i32 = 127,
    i64 = 126,
    f32 = 125,
    f64 = 124
}
export declare enum RefType {
    funcRef = 112,
    externRef = 111
}
export declare enum ValueBlockType {
    i32 = -1,
    i64 = -2,
    f32 = -3,
    f64 = -4,
    AnyFunc = -32,
    Empty = -64
}
export declare type BlockType = {
    valueType: ValueBlockType;
} | {
    typeIndex: number;
};
export declare type ValueType = RefType | NumType;
export interface FuncType {
    paramTypes: ValueType[];
    returnTypes: ValueType[];
}
export interface Section<Id extends number, Item> {
    id: Id;
    items: Item[];
}
export interface CustomSection {
    id: 0;
    name: string;
    contents: Uint8Array;
}
export declare type TypeSection = Section<1, FuncType>;
export declare type ImportSection = Section<2, Import>;
export declare type FunctionSection = Section<3, number>;
export declare type TableSection = Section<4, TableType>;
export declare type MemorySection = Section<5, ResizableLimits>;
export declare type GlobalSection = Section<6, Global>;
export declare type ExportSection = Section<7, Export>;
export interface StartSection {
    id: 8;
    startFunction: number;
}
export declare type ElementSection = Section<9, Element>;
export declare type CodeSection = Section<10, Code>;
export declare type DataSection = Section<11, Data>;
export interface DataCountSection {
    id: 12;
    dataCount: number;
}
export declare enum ExternalKind {
    Function = 0,
    Table = 1,
    Memory = 2,
    Global = 3
}
export interface Import {
    module: string;
    field: string;
    description: {
        kind: ExternalKind.Function;
        typeIndex: number;
    } | {
        kind: ExternalKind.Table;
        tableType: TableType;
    } | {
        kind: ExternalKind.Memory;
        memoryType: ResizableLimits;
    } | {
        kind: ExternalKind.Global;
        globalType: GlobalType;
    };
}
export interface TableType {
    elementType: RefType;
    limits: ResizableLimits;
}
export interface ResizableLimits {
    minimum: number;
    maximum?: number;
}
export interface GlobalType {
    type: ValueType;
    mutability: boolean;
}
export interface Global {
    type: GlobalType;
    initExpr: Expr;
}
export declare enum ElementKind {
    FuncRef = 0
}
export declare type Element = {
    id: 0x00;
    offsetExpr: Expr;
    functionIds: FuncId[];
} | {
    id: 0x01;
    kind: ElementKind;
    functionIds: FuncId[];
} | {
    id: 0x02;
    tableIndex: number;
    offsetExpr: Expr;
    kind: ElementKind;
    functionIds: FuncId[];
} | {
    id: 0x03;
    kind: ElementKind;
    functionIds: FuncId[];
} | {
    id: 0x04;
    offsetExpr: Expr;
    initExprs: Expr[];
} | {
    id: 0x05;
    refType: RefType;
    initExprs: Expr[];
} | {
    id: 0x06;
    tableIndex: number;
    offsetExpr: Expr;
    refType: RefType;
    initExprs: Expr[];
} | {
    id: 0x07;
    refType: RefType;
    initExprs: Expr[];
};
export declare type LocalVariables = Map<ValueType, number>;
export interface Code {
    locals: LocalVariables;
    code: Expr;
}
export declare type Data = {
    id: 0x00;
    offsetExpr: Expr;
    bytes: Uint8Array;
} | {
    id: 0x01;
    bytes: Uint8Array;
} | {
    id: 0x02;
    memoryIndex: number;
    offsetExpr: Expr;
    bytes: Uint8Array;
};
export interface Export {
    name: string;
    kind: ExternalKind;
    index: number;
}
export interface Module {
    types: TypeSection;
    imports: ImportSection;
    functions: FunctionSection;
    tables: TableSection;
    memories: MemorySection;
    globals: GlobalSection;
    exports: ExportSection;
    start?: StartSection;
    elements: ElementSection;
    code: CodeSection;
    data: DataSection;
    dataCount?: DataCountSection;
    customSections: CustomSection[];
}
export declare enum InstrType {
    Unreachable = 0,
    Nop = 1,
    Block = 2,
    Loop = 3,
    If = 4,
    Else = 5,
    Br = 12,
    BrIf = 13,
    BrTable = 14,
    Return = 15,
    Call = 16,
    CallIndirect = 17,
    RefNull = 208,
    RefIsNull = 209,
    RefFunc = 210,
    Drop = 26,
    Select = 27,
    SelectT = 28,
    LocalGet = 32,
    LocalSet = 33,
    LocalTee = 34,
    GlobalGet = 35,
    GlobalSet = 36,
    TableGet = 37,
    TableSet = 38,
    I32Load = 40,
    I64Load = 41,
    F32Load = 42,
    F64Load = 43,
    I32Load8S = 44,
    I32Load8U = 45,
    I32Load16S = 46,
    I32Load16U = 47,
    I64Load8S = 48,
    I64Load8U = 49,
    I64Load16S = 50,
    I64Load16U = 51,
    I64Load32S = 52,
    I64Load32U = 53,
    I32Store = 54,
    I64Store = 55,
    F32Store = 56,
    F64Store = 57,
    I32Store8 = 58,
    I32Store16 = 59,
    I64Store8 = 60,
    I64Store16 = 61,
    I64Store32 = 62,
    MemorySize = 63,
    MemoryGrow = 64,
    I32Const = 65,
    I64Const = 66,
    F32Const = 67,
    F64Const = 68,
    I32EqZ = 69,
    I32Eq = 70,
    I32Ne = 71,
    I32LtS = 72,
    I32LtU = 73,
    I32GtS = 74,
    I32GtU = 75,
    I32LeS = 76,
    I32LeU = 77,
    I32GeS = 78,
    I32GeU = 79,
    I64EqZ = 80,
    I64Eq = 81,
    I64Ne = 82,
    I64LtS = 83,
    I64LtU = 84,
    I64GtS = 85,
    I64GtU = 86,
    I64LeS = 87,
    I64LeU = 88,
    I64GeS = 89,
    I64GeU = 90,
    F32Eq = 91,
    F32Ne = 92,
    F32Lt = 93,
    F32Gt = 94,
    F32Le = 95,
    F32Ge = 96,
    F64Eq = 97,
    F64Ne = 98,
    F64Lt = 99,
    F64Gt = 100,
    F64Le = 101,
    F64Ge = 102,
    I32Clz = 103,
    I32Ctz = 104,
    I32Popcnt = 105,
    I32Add = 106,
    I32Sub = 107,
    I32Mul = 108,
    I32DivS = 109,
    I32DivU = 110,
    I32RemS = 111,
    I32RemU = 112,
    I32And = 113,
    I32Or = 114,
    I32Xor = 115,
    I32Shl = 116,
    I32ShrS = 117,
    I32ShrU = 118,
    I32Rotl = 119,
    I32Rotr = 120,
    I64Clz = 121,
    I64Ctz = 122,
    I64Popcnt = 123,
    I64Add = 124,
    I64Sub = 125,
    I64Mul = 126,
    I64DivS = 127,
    I64DivU = 128,
    I64RemS = 129,
    I64RemU = 130,
    I64And = 131,
    I64Or = 132,
    I64Xor = 133,
    I64Shl = 134,
    I64ShrS = 135,
    I64ShrU = 136,
    I64Rotl = 137,
    I64Rotr = 138,
    F32Abs = 139,
    F32Neg = 140,
    F32Ceil = 141,
    F32Floor = 142,
    F32Trunc = 143,
    F32Nearest = 144,
    F32Sqrt = 145,
    F32Add = 146,
    F32Sub = 147,
    F32Mul = 148,
    F32Div = 149,
    F32Min = 150,
    F32Max = 151,
    F32CopySign = 152,
    F64Abs = 153,
    F64Neg = 154,
    F64Ceil = 155,
    F64Floor = 156,
    F64Trunc = 157,
    F64Nearest = 158,
    F64Sqrt = 159,
    F64Add = 160,
    F64Sub = 161,
    F64Mul = 162,
    F64Div = 163,
    F64Min = 164,
    F64Max = 165,
    F64CopySign = 166,
    I32WrapI64 = 167,
    I32TruncF32S = 168,
    I32TruncF32U = 169,
    I32TruncF64S = 170,
    I32TruncF64U = 171,
    I64ExtendI32S = 172,
    I64ExtendI32U = 173,
    I64TruncF32S = 174,
    I64TruncF32U = 175,
    I64TruncF64S = 176,
    I64TruncF64U = 177,
    F32ConvertI32S = 178,
    F32ConvertI32U = 179,
    F32ConvertI64S = 180,
    F32ConvertI64U = 181,
    F32DemoteF64 = 182,
    F64ConvertI32S = 183,
    F64ConvertI32U = 184,
    F64ConvertI64S = 185,
    F64ConvertI64U = 186,
    F64PromoteF32 = 187,
    I32ReinterpretF32 = 188,
    I64ReinterpretF64 = 189,
    F32ReinterpretI32 = 190,
    F64ReinterpretI64 = 191,
    I32Extend8S = 192,
    I32Extend16S = 193,
    I64Extend8S = 194,
    I64Extend16S = 195,
    I64Extend32S = 196,
    Other = 252
}
export declare enum OtherInstrType {
    I32TruncSatF32S = 0,
    I32TruncSatF32U = 1,
    I32TruncSatF64S = 2,
    I32TruncSatF64U = 3,
    I64TruncSatF32S = 4,
    I64TruncSatF32U = 5,
    I64TruncSatF64S = 6,
    I64TruncSatF64U = 7,
    MemoryInit = 8,
    DataDrop = 9,
    MemoryCopy = 10,
    MemoryFill = 11,
    TableInit = 12,
    ElemDrop = 13,
    TableCopy = 14,
    TableGrow = 15,
    TableSize = 16,
    TableFill = 17
}
export declare type Instruction = [InstrType.Unreachable] | [InstrType.Nop] | [InstrType.Return] | [InstrType.RefIsNull] | [InstrType.Drop] | [InstrType.Select] | [InstrType.I32EqZ] | [InstrType.I32Eq] | [InstrType.I32Ne] | [InstrType.I32LtS] | [InstrType.I32LtU] | [InstrType.I32GtS] | [InstrType.I32GtU] | [InstrType.I32LeS] | [InstrType.I32LeU] | [InstrType.I32GeS] | [InstrType.I32GeU] | [InstrType.I64EqZ] | [InstrType.I64Eq] | [InstrType.I64Ne] | [InstrType.I64LtS] | [InstrType.I64LtU] | [InstrType.I64GtS] | [InstrType.I64GtU] | [InstrType.I64LeS] | [InstrType.I64LeU] | [InstrType.I64GeS] | [InstrType.I64GeU] | [InstrType.F32Eq] | [InstrType.F32Ne] | [InstrType.F32Lt] | [InstrType.F32Gt] | [InstrType.F32Le] | [InstrType.F32Ge] | [InstrType.F64Eq] | [InstrType.F64Ne] | [InstrType.F64Lt] | [InstrType.F64Gt] | [InstrType.F64Le] | [InstrType.F64Ge] | [InstrType.I32Clz] | [InstrType.I32Ctz] | [InstrType.I32Popcnt] | [InstrType.I32Add] | [InstrType.I32Sub] | [InstrType.I32Mul] | [InstrType.I32DivS] | [InstrType.I32DivU] | [InstrType.I32RemS] | [InstrType.I32RemU] | [InstrType.I32And] | [InstrType.I32Or] | [InstrType.I32Xor] | [InstrType.I32Shl] | [InstrType.I32ShrS] | [InstrType.I32ShrU] | [InstrType.I32Rotl] | [InstrType.I32Rotr] | [InstrType.I64Clz] | [InstrType.I64Ctz] | [InstrType.I64Popcnt] | [InstrType.I64Add] | [InstrType.I64Sub] | [InstrType.I64Mul] | [InstrType.I64DivS] | [InstrType.I64DivU] | [InstrType.I64RemS] | [InstrType.I64RemU] | [InstrType.I64And] | [InstrType.I64Or] | [InstrType.I64Xor] | [InstrType.I64Shl] | [InstrType.I64ShrS] | [InstrType.I64ShrU] | [InstrType.I64Rotl] | [InstrType.I64Rotr] | [InstrType.F32Abs] | [InstrType.F32Neg] | [InstrType.F32Ceil] | [InstrType.F32Floor] | [InstrType.F32Trunc] | [InstrType.F32Nearest] | [InstrType.F32Sqrt] | [InstrType.F32Add] | [InstrType.F32Sub] | [InstrType.F32Mul] | [InstrType.F32Div] | [InstrType.F32Min] | [InstrType.F32Max] | [InstrType.F32CopySign] | [InstrType.F64Abs] | [InstrType.F64Neg] | [InstrType.F64Ceil] | [InstrType.F64Floor] | [InstrType.F64Trunc] | [InstrType.F64Nearest] | [InstrType.F64Sqrt] | [InstrType.F64Add] | [InstrType.F64Sub] | [InstrType.F64Mul] | [InstrType.F64Div] | [InstrType.F64Min] | [InstrType.F64Max] | [InstrType.F64CopySign] | [InstrType.I32WrapI64] | [InstrType.I32TruncF32S] | [InstrType.I32TruncF32U] | [InstrType.I32TruncF64S] | [InstrType.I32TruncF64U] | [InstrType.I64ExtendI32S] | [InstrType.I64ExtendI32U] | [InstrType.I64TruncF32S] | [InstrType.I64TruncF32U] | [InstrType.I64TruncF64S] | [InstrType.I64TruncF64U] | [InstrType.F32ConvertI32S] | [InstrType.F32ConvertI32U] | [InstrType.F32ConvertI64S] | [InstrType.F32ConvertI64U] | [InstrType.F32DemoteF64] | [InstrType.F64ConvertI32S] | [InstrType.F64ConvertI32U] | [InstrType.F64ConvertI64S] | [InstrType.F64ConvertI64U] | [InstrType.F64PromoteF32] | [InstrType.I32ReinterpretF32] | [InstrType.I64ReinterpretF64] | [InstrType.F32ReinterpretI32] | [InstrType.F64ReinterpretI64] | [InstrType.I32Extend8S] | [InstrType.I32Extend16S] | [InstrType.I64Extend8S] | [InstrType.I64Extend16S] | [InstrType.I64Extend32S] | [InstrType.Block, BlockType, Expr] | [InstrType.Loop, BlockType, Expr] | [InstrType.If, BlockType, Expr] | [InstrType.If, BlockType, Expr, Expr] | [InstrType.Else] | [InstrType.Br, number] | [InstrType.BrIf, number] | [InstrType.BrTable, number[], number] | [InstrType.Call, number] | [InstrType.CallIndirect, number, number] | [InstrType.RefNull, RefType] | [InstrType.RefFunc, number] | [InstrType.SelectT, ValueType[]] | [InstrType.LocalGet, number] | [InstrType.LocalSet, number] | [InstrType.LocalTee, number] | [InstrType.GlobalGet, number] | [InstrType.GlobalSet, number] | [InstrType.TableGet, number] | [InstrType.TableSet, number] | [InstrType.Other, OtherInstrType.I32TruncSatF32S] | [InstrType.Other, OtherInstrType.I32TruncSatF32U] | [InstrType.Other, OtherInstrType.I32TruncSatF64S] | [InstrType.Other, OtherInstrType.I32TruncSatF64U] | [InstrType.Other, OtherInstrType.I64TruncSatF32S] | [InstrType.Other, OtherInstrType.I64TruncSatF32U] | [InstrType.Other, OtherInstrType.I64TruncSatF64S] | [InstrType.Other, OtherInstrType.I64TruncSatF64U] | [InstrType.Other, OtherInstrType.MemoryInit, number] | [InstrType.Other, OtherInstrType.DataDrop, number] | [InstrType.Other, OtherInstrType.MemoryCopy] | [InstrType.Other, OtherInstrType.MemoryFill] | [InstrType.Other, OtherInstrType.TableInit, number, number] | [InstrType.Other, OtherInstrType.ElemDrop, number] | [InstrType.Other, OtherInstrType.TableCopy, number, number] | [InstrType.Other, OtherInstrType.TableGrow, number] | [InstrType.Other, OtherInstrType.TableSize, number] | [InstrType.Other, OtherInstrType.TableFill, number] | [InstrType.I32Load, number, number] | [InstrType.I64Load, number, number] | [InstrType.F32Load, number, number] | [InstrType.F64Load, number, number] | [InstrType.I32Load8S, number, number] | [InstrType.I32Load8U, number, number] | [InstrType.I32Load16S, number, number] | [InstrType.I32Load16U, number, number] | [InstrType.I64Load8S, number, number] | [InstrType.I64Load8U, number, number] | [InstrType.I64Load16S, number, number] | [InstrType.I64Load16U, number, number] | [InstrType.I64Load32S, number, number] | [InstrType.I64Load32U, number, number] | [InstrType.I32Store, number, number] | [InstrType.I64Store, number, number] | [InstrType.F32Store, number, number] | [InstrType.F64Store, number, number] | [InstrType.I32Store8, number, number] | [InstrType.I32Store16, number, number] | [InstrType.I64Store8, number, number] | [InstrType.I64Store16, number, number] | [InstrType.I64Store32, number, number] | [InstrType.MemorySize] | [InstrType.MemoryGrow] | [InstrType.I32Const, number] | [InstrType.I64Const, number] | [InstrType.F32Const, number] | [InstrType.F64Const, number];
export interface Expr {
    instructions: Instruction[];
    length: number;
}
export {};
